summaryrefslogtreecommitdiffstats
path: root/kig/misc/argsparser.h
diff options
context:
space:
mode:
Diffstat (limited to 'kig/misc/argsparser.h')
-rw-r--r--kig/misc/argsparser.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/kig/misc/argsparser.h b/kig/misc/argsparser.h
index a3aff562..001d9359 100644
--- a/kig/misc/argsparser.h
+++ b/kig/misc/argsparser.h
@@ -26,7 +26,7 @@ class ObjectImpType;
/**
* This class is meant to take care of checking the types of the
* tqparents to ObjectCalcer's, and to put them in the correct order.
* An ObjectType should construct an ArgsParser with a specification
* of the arguments it wants. This specification is given as an array
* of ArgsParser::spec structs. This struct contains a pointer to an
@@ -117,7 +117,7 @@ private:
*/
std::vector<spec> margs;
- spec findSpec( const ObjectImp* o, const Args& tqparents ) const;
+ spec findSpec( const ObjectImp* o, const Args& parents ) const;
public:
ArgsParser( const struct spec* args, int n );
ArgsParser( const std::vector<spec>& args );
@@ -137,7 +137,7 @@ public:
int check( const std::vector<ObjectCalcer*>& os ) const;
/**
* returns the usetext for the argument that o would be used for,
- * if sel were used as tqparents..
+ * if sel were used as parents..
* \p o should be in \p sel ...
*/
std::string usetext( const ObjectImp* o, const Args& sel ) const;
@@ -155,16 +155,16 @@ public:
/**
* returns the minimal ObjectImp ID that \p o needs to inherit in order
* to be useful.. \p o should be part of \p tqparents .
*/
- const ObjectImpType* impRequirement( const ObjectImp* o, const Args& tqparents ) const;
+ const ObjectImpType* impRequirement( const ObjectImp* o, const Args& parents ) const;
/**
* Supposing that \p tqparents would be given as tqparents, this function
* returns whether the returned ObjectImp will be, by construction,
* on \p o ( if \p o is a curve ), or through \p o ( if \p o is a point ).
*/
- bool isDefinedOnOrThrough( const ObjectImp* o, const Args& tqparents ) const;
+ bool isDefinedOnOrThrough( const ObjectImp* o, const Args& parents ) const;
// Checks the args according to this args specification. If the
// objects should never have occurred, then an assertion failure
@@ -26,7 +26,7 @@ class ObjectImpType;
/**
* This class is meant to take care of checking the types of the
- * tqparents to ObjectCalcer's, and to put them in the correct order.
+ * parents to ObjectCalcer's, and to put them in the correct order.
* An ObjectType should construct an ArgsParser with a specification
* of the arguments it wants. This specification is given as an array
@@ -155,16 +155,16 @@ public:
/**
* returns the minimal ObjectImp ID that \p o needs to inherit in order
- * to be useful.. \p o should be part of \p tqparents .
+ * to be useful.. \p o should be part of \p parents .
*/
@@ -155,16 +155,16 @@ public:
/**
- * Supposing that \p tqparents would be given as tqparents, this function
+ * Supposing that \p parents would be given as parents, this function
* returns whether the returned ObjectImp will be, by construction,
* on \p o ( if \p o is a curve ), or through \p o ( if \p o is a point ).